@@ -1,6 +1,6 @@
 package WWW::Google::Places::SearchResult;
 
-$WWW::Google::Places::SearchResult::VERSION   = '0.18';
+$WWW::Google::Places::SearchResult::VERSION   = '0.19';
 $WWW::Google::Places::SearchResult::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,11 +9,14 @@ WWW::Google::Places::SearchResult - Placeholder for Search Result for WWW::Googl
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
 use 5.006;
+use Data::Dumper;
+use WWW::Google::Places::Geometry;
+
 use Moo;
 use namespace::clean;
 
@@ -21,26 +24,50 @@ has 'place_id' => (is => 'ro');
 has 'name'     => (is => 'ro');
 has 'types'    => (is => 'ro');
 has 'geometry' => (is => 'ro');
-has 'icon'     => (is => 'ro');
-has 'vicinity' => (is => 'ro');
-has 'scope'    => (is => 'ro');
+has 'icon'     => (is => 'ro', default => 'N/A');
+has 'vicinity' => (is => 'ro', default => 'N/A');
+has 'scope'    => (is => 'ro', default => 'GOOGLE');
+
+sub BUILDARGS {
+    my ($class, $args) = @_;
+
+    if (exists $args->{geometry}) {
+        $args->{geometry} = WWW::Google::Places::Geometry->new($args->{geometry});
+    }
+
+    return $args;
+}
 
 =head1 METHODS
 
 =head2 place_id()
 
+Returns the place id.
+
 =head2 name()
 
+Returns place name.
+
 =head2 types()
 
+Returns ref to a list of place types.
+
 =head2 geometry()
 
+Returns an object of type L<WWW::Google::Places::Geometry>.
+
 =head2 icon()
 
+Returns URL of the link to the place icon.
+
 =head2 vicinity()
 
+Returns the vicinity of place.
+
 =head2 scope()
 
+Returns the place search scope.
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
